diff -Naur dillo-0.8.6.ori/src/html.c dillo-0.8.6/src/html.c
--- dillo-0.8.6.ori/src/html.c	2006-04-12 17:50:35.000000000 +0200
+++ dillo-0.8.6/src/html.c	2007-05-10 10:03:37.916574429 +0200
@@ -4,6 +4,7 @@
  * Copyright (C) 1997 Raph Levien <raph@acm.org>
  * Copyright (C) 1999 James McCollough <jamesm@gtwn.net>
  * Copyright (C) 2000-2004 Jorge Arellano Cid <jcid@dillo.org>
+ * Modifications for charset translations: Dario Rodriguez <dario@softhome.net>
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -29,7 +30,10 @@
 #include <stdio.h>      /* for sprintf */
 #include <math.h>      /* for rint */
 #include <errno.h>
-
+#include <sys/types.h>
+#include <sys/stat.h>
+#include <unistd.h>
+#include <fcntl.h>
 #include <gtk/gtk.h>
 
 #include "msg.h"
@@ -806,6 +810,8 @@
 
    html->attr_data = g_string_sized_new(1024);
 
+   html->CharsetUTF8=0;
+
    Html_set_dwpage(html);
 
    return html;
@@ -3318,9 +3324,11 @@
 " <a href='%s'>here</a>%s</td></tr></table><br>\n";
 
    const gchar *equiv, *content;
+   const gchar *charset;
    gchar *html_msg, delay_str[64];
    gint delay;
 
+   MSG("Html_tag_open_meta: entered\n");
    /* only valid inside HEAD */
    if (!(html->InFlags & IN_HEAD)) {
       MSG_HTML("META elements must be inside the HEAD section\n");
@@ -3354,6 +3362,22 @@
       }
       g_free(html_msg);
    }
+   if((equiv = Html_get_attr(html, tag, tagsize, "http-equiv")) &&
+       (content = Html_get_attr(html, tag, tagsize, "content"))) {
+       MSG("Html_tag_open_meta: content found: %s\n",content);
+       for(charset=strchr(content,'c');charset!=NULL;charset=strchr(charset+1,'c')) {
+          if(memcmp(charset,"charset",7)==0) {
+                charset+=7;
+                while(*charset==' ' || *charset=='=' || *charset=='\t')
+                        charset++;
+                MSG("Html_tag_open_meta: charset found: %s\n",charset);
+                if(strcmp(charset,"utf-8")==0 || strcmp(charset,"UTF-8")==0)
+                        html->CharsetUTF8=1;
+                break;
+          }
+       }
+   }
+   MSG("Html_tag_open_meta: exited\n");
 }
 
 /*
@@ -5136,8 +5160,29 @@
             break;
          }
          if (buf_index < bufsize || Eof) {
-            /* successfully found end of token */
-            Html_process_word(html, buf + token_start,
+            if(html->CharsetUTF8!=0) {
+                /* Modify the text in the buffer (!!!) */
+                int i,n;
+                int l;
+                unsigned char *ptr;
+                l=buf_index-token_start;
+                ptr=((unsigned char *)buf)+token_start;
+                for(i=0,n=0;i<l;i++) {
+                        if(i!=(l-1) && (ptr[i]==0xc2 || ptr[i]==0xc3) && ptr[i+1]>=0x80 && ptr[i+1]<=0xbf) {
+                                ptr[i+1]=ptr[i+1]|((ptr[i]&0x3)<<6);
+                                n++;
+                                i++;
+                        }
+                        ptr[i-n]=ptr[i];
+                }
+                for(i=(l-n);i<l;i++)
+                        ptr[i]=' ';
+                l-=n;
+                Html_process_word(html, buf + token_start,
+                              l);
+            } else
+               /* successfully found end of token */
+               Html_process_word(html, buf + token_start,
                               buf_index - token_start);
             token_start = buf_index;
          }
diff -Naur dillo-0.8.6.ori/src/html.h dillo-0.8.6/src/html.h
--- dillo-0.8.6.ori/src/html.h	2006-01-13 17:05:20.000000000 +0100
+++ dillo-0.8.6/src/html.h	2007-05-10 10:03:37.917574277 +0200
@@ -236,6 +236,9 @@
    GString *attr_data;
 
    BrowserWindow *bw;
+
+   /* charset support */
+   int CharsetUTF8;
 };
 
 #ifdef __cplusplus
